==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/PriceVolumeTrendIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PriceVolumeTrendIndicatorDescription } from "./PriceVolumeTrendIndicatorDescription";
/**
 * @hidden
 */
var PriceVolumeTrendIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PriceVolumeTrendIndicatorDescriptionMetadata, _super);
    function PriceVolumeTrendIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicatorDescriptionMetadata.b = function (a) {
        if (PriceVolumeTrendIndicatorDescriptionMetadata.a == null) {
            PriceVolumeTrendIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PriceVolumeTrendIndicatorDescriptionMetadata.c(PriceVolumeTrendIndicatorDescriptionMetadata.a);
        }
        if (a.g(PriceVolumeTrendIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(PriceVolumeTrendIndicatorDescriptionMetadata.a);
    };
    PriceVolumeTrendIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    PriceVolumeTrendIndicatorDescriptionMetadata.d = function (a) {
        PriceVolumeTrendIndicatorDescriptionMetadata.b(a);
        a.u("PriceVolumeTrendIndicator", function () { return new PriceVolumeTrendIndicatorDescription(); });
        a.t("PriceVolumeTrendIndicator", PriceVolumeTrendIndicatorDescriptionMetadata.a);
    };
    PriceVolumeTrendIndicatorDescriptionMetadata.$t = markType(PriceVolumeTrendIndicatorDescriptionMetadata, 'PriceVolumeTrendIndicatorDescriptionMetadata');
    PriceVolumeTrendIndicatorDescriptionMetadata.a = null;
    return PriceVolumeTrendIndicatorDescriptionMetadata;
}(Base));
export { PriceVolumeTrendIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/PriceVolumeTrendIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PriceVolumeTrendIndicatorDescription } from "./PriceVolumeTrendIndicatorDescription";
/**
 * @hidden
 */
var PriceVolumeTrendIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PriceVolumeTrendIndicatorDescriptionMetadata, _super);
    function PriceVolumeTrendIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicatorDescriptionMetadata.b = function (a) {
        if (PriceVolumeTrendIndicatorDescriptionMetadata.a == null) {
            PriceVolumeTrendIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PriceVolumeTrendIndicatorDescriptionMetadata.c(PriceVolumeTrendIndicatorDescriptionMetadata.a);
        }
        if (a.j(PriceVolumeTrendIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(PriceVolumeTrendIndicatorDescriptionMetadata.a);
    };
    PriceVolumeTrendIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
    };
    PriceVolumeTrendIndicatorDescriptionMetadata.d = function (a) {
        PriceVolumeTrendIndicatorDescriptionMetadata.b(a);
        a.aa("PriceVolumeTrendIndicator", function () { return new PriceVolumeTrendIndicatorDescription(); });
        a.z("PriceVolumeTrendIndicator", PriceVolumeTrendIndicatorDescriptionMetadata.a);
    };
    PriceVolumeTrendIndicatorDescriptionMetadata.$t = markType(PriceVolumeTrendIndicatorDescriptionMetadata, 'PriceVolumeTrendIndicatorDescriptionMetadata');
    PriceVolumeTrendIndicatorDescriptionMetadata.a = null;
    return PriceVolumeTrendIndicatorDescriptionMetadata;
}(Base));
export { PriceVolumeTrendIndicatorDescriptionMetadata };
